﻿namespace Af360StiSample.Data;

public class CustomerSettlementDatasetResult 
{
    public ClerkedLotsCustomersDataset Settlement { get; set; }
    public AuctionDataset Auction { get; set; }
    public BuyerDataset Bidder { get; set; }
}


public class CustomerDataset
{
    public int CustomerId { get; set; }
    public string FirstName { get; set; }
    public string MiddleName { get; set; }
    public string LastName { get; set; }
    public string CustomerCode { get; set; }
    public string Email { get; set; }
    public string Company { get; set; }
    public string BillToAddress1 { get; set; }
    public string BillToAddress2 { get; set; }
    public string BillToCity { get; set; }
    public string BillToState { get; set; }
    public string BillToZip { get; set; }
    public string BillToCountry { get; set; }
    public string ShipToAddress1 { get; set; }
    public string ShipToAddress2 { get; set; }
    public string ShipToCity { get; set; }
    public string ShipToState { get; set; }
    public string ShipToZip { get; set; }
    public string ShipToCountry { get; set; }
    public string Phone1 { get; set; }
    public string Phone2 { get; set; }
}


public class BuyerDataset : CustomerDataset
{
    public string InvoiceNumber { get; set; }
    public int? BidderNumber { get; set; }
    public decimal Balance { get; set; }
}

public class OrganizationDataset
{
    public string OrganizationName { get; set; } = string.Empty;
    public string OrganizationAddress1 { get; set; } = string.Empty;
    public string OrganizationAddress2 { get; set; } = string.Empty;
    public string OrganizationPhone { get; set; } = string.Empty;
    public string OrganizationCity { get; set; } = string.Empty;
    public string OrganizationState { get; set; } = string.Empty;
    public string OrganizationZip { get; set; } = string.Empty;
}

public class AuctionDataset : OrganizationDataset
{
    public string AuctionCode { get; set; } = string.Empty;
    public string AuctionName { get; set; } = string.Empty;
    public DateTime? AuctionStartDate { get; set; } = null;
    public DateTime? AuctionLocalStartDate { get; set; } = null;
    public DateTime? AuctionEndDate { get; set; } = null;
    public DateTime? AuctionLocalEndDate { get; set; } = null;
    public IEnumerable<LotDataset> Lots { get; set; } = [];
    public string AuctionShippingPickUpInformation { get; set; } = string.Empty;
    public string AuctionTimezoneId { get; set; } = string.Empty;

    public DateTime? AuctionCloseTime { get; set; } = null;
    public string AuctionAddress1 { get; set; } = string.Empty;
    public string AuctionAddress2 { get; set; } = string.Empty;
    public string AuctionPhone { get; set; } = string.Empty;
    public string AuctionCity { get; set; } = string.Empty;
    public string AuctionState { get; set; } = string.Empty;
    public string AuctionZip { get; set; } = string.Empty;
}

public class LotDataset
{
    public string LotNumber { get; set; } = "";
    public string LotLead { get; set; } = "";
    public decimal Quantity { get; set; }
    public decimal QuantitySold { get; set; }
    public string Status { get; set; }
    public int? BoughtByBidderNumber { get; set; }
    public int? LotNumberSort { get; set; }
    public int? LotNumberSubSort { get; set; }
}


public class ClerkedLotsCustomersDataset
{
    public int CustomerId { get; set; }
    public int? BidderNumber { get; set; }
    public string CustomerCode { get; set; }
    public string FirstName { get; set; }
    public string LastName { get; set; }
    public string Email { get; set; }
    public string Name => $"{FirstName} {LastName}";
    public List<SettlementLineDataset> SettlementLines { get; set; } = [];
    public List<LotChargeLineDataset> GroupedChargeLines { get; set; } = [];
    public int LotCount { get; set; }
    public decimal Balance { get; set; }
    public int? HiBidBuyerId { get; set; }
    public bool IsHiBidCashBuyer { get; set; }
    public string InvoiceId { get; set; }
    public string InvoiceStatus { get; set; }
    public string InvoiceNumber { get; set; }
    public string PaymentProcessor { get; set; }
    public bool IsSeller { get; set; }
    public DepositDataset Deposit { get; set; }
}

public class SettlementLineDataset
{
    public int? LotId { get; set; }
    public string LotNumber { get; set; }
    public int? LotNumberSort { get; set; }
    public int? LotNumberSubSort { get; set; }
    public bool? IsTimesMoney { get; set; }
    public string Lead { get; set; }
    public string Description { get; set; }
    public string BidderOrSeller { get; set; }
    public decimal? QuantitySold { get; set; }
    public List<SettlementEntryDataset> Entries { get; set; } = [];
    public bool ShippedOrPickedUp { get; set; }
    public string VINSerialNumber { get; set; }
    public string StockNumber { get; set; }
    public string LotGroup { get; set; }
}

public class SettlementEntryDataset
{
    public int Id { get; set; }
    public string Description { get; set; }
    public int JournalId { get; set; }
    public TransactionType Type { get; set; }
    public decimal Amount { get; set; }
    public bool IsDebit { get; set; }
    public int? CustomerId { get; set; }
    public int? LotId { get; set; }
    public int FormulaId { get; set; }
}

public enum TransactionType
{
    /**
     * Transaction types allowed under JournalType = SOLD_LOT, BUY_BACK_LOT, PASSED_LOT
     */
    LOT_SETTLEMENT = 0,
    BUYERS_PREMIUM,
    BUYER_LOT_CHARGES,
    BUYER_TAX,
    AUCTIONEER_COMMISSION,
    SELLER_TAX,
    SALESPERSON_LOT_COMMISSION,
    /**
     * Transaction types allowed under JournalType = RECEIPTS_FROM_CUSTOMER
     */
    RECEIPT_FROM_CUSTOMER,
    WITH_DISCOUNT,
    WITH_SURCHARGE,
    WITH_ROUNDING,
    /**
     * Transaction types allowed under JournalType = STAND_ALONE
     */
    SELLER_AUCTION_EXPENSE,
    SELLER_LOT_EXPENSE,
    AUCTION_EXPENSE,
    AUCTION_MARKETING_EXPENSE,
    AUCTION_LOT_EXPENSE,
    BUYER_AUCTION_CHARGES,
    PAY_CUSTOMER,
    BUYER_AUCTION_DEPOSIT,
}

public class LotChargeLineDataset
{
    public string Description { get; set; }
    public decimal Amount { get; set; }
}

public class DepositDataset
{
    public int BidderDepositID { get; set; }
    public int BidderID { get; set; }
    public decimal DepositAmount { get; set; }
    public decimal DepositAmountApplied { get; set; }
    public decimal DepositAmountReturned { get; set; }
    public string DepositNotes { get; set; }
    public DateTime DepositDate { get; set; }
    public PaymentType DepositPaymentType { get; set; }
    public decimal DepositAmountRemaining =>
        DepositAmount - DepositAmountApplied - DepositAmountReturned;
}

public enum PaymentType : short
{
    CASH,
    CHECK,
    MASTERCARD,
    VISA,
    AMERICAN_EXPRESS,
    DISCOVER,
    GLOBAL_PAYMENTS_ACH,
    GLOBAL_PAYMENTS,
    PAYPAL,
    CURRENCY_PAY,
}
