﻿using Stimulsoft.Report;

namespace Af360StiSample.Data;

public static class ReportDataBinder
{
    public static StiReport CreateFromDefinition(string definition)
    {
        var stiReport = new StiReport();

        stiReport.LoadFromJson(definition);
		
        AddCustomScript(stiReport);

        return stiReport;
    }

    private static void AddCustomScript(StiReport stiReport)
    {
        stiReport.ReferencedAssemblies = REFERENCE_ASSEMBLIES;
        stiReport.Script = STI_CUSTOM_REPORT_SCRIPT;
    }

    public static void BindDataSource(StiReport report, object datasetModel)
    {
        var dataSource = datasetModel as CustomerSettlementDatasetResult;

        if (dataSource == null)
        {
            throw new InvalidCastException(
                $"datasetModel must be of type {typeof(CustomerSettlementDatasetResult)}");
        }

        report.RegData("Customer Settlement", dataSource.Bidder);
        report.RegData("Customer Settlement", dataSource.Auction);
        report.RegData("Customer Settlement", dataSource.Settlement);
    }

    private static readonly string[] REFERENCE_ASSEMBLIES = 
    [
        "System.Dll",
        "System.Drawing.Dll",
        "System.Windows.Forms.Dll",
        "System.Data.Dll",
        "System.Xml.Dll",
        "Stimulsoft.Controls.Dll",
        "Stimulsoft.Base.Dll",
        "Stimulsoft.Report.Dll",
        "Af360StiSample.Dll",
    ];
	

    private const string STI_CUSTOM_REPORT_SCRIPT =
        """
        using System;
        using System.Drawing;
        using System.Windows.Forms;
        using System.Data;
        using Stimulsoft.Controls;
        using Stimulsoft.Base.Drawing;
        using Stimulsoft.Report;
        using Stimulsoft.Report.Dialogs;
        using Stimulsoft.Report.Components;
        using Af360StiSample.Data;
        
        namespace Reports
        {
            public class Report : Stimulsoft.Report.StiReport
            {
                public Report()        {
                    this.InitializeComponent();
                }
        
                #region StiReport Designer generated code - do not modify
                #endregion StiReport Designer generated code - do not modify
            }
        }
        """;
}