﻿namespace Af360StiSample.Data;

public class SampleDataFactory
{
    public static readonly AuctionDataset SAMPLE_AUCTION = new()
    {
        AuctionCode = "A123",
        AuctionEndDate = new DateTime(DateTime.Now.Year + 1, 2, 1),
        AuctionName = "Surplus Items Auction",
        AuctionStartDate = new DateTime(DateTime.Now.Year + 1, 1, 1),
        AuctionTimezoneId = "Eastern Standard Time",
        AuctionShippingPickUpInformation = "Shipping pick-up Instructions",
        Lots = [
		
            new()
            {
                LotLead = "Lot 1",
                LotNumber = "1",
                LotNumberSort = 1,
                LotNumberSubSort = 1,
                Quantity = 1,
                QuantitySold = 1,
                Status = "SOLD",
                BoughtByBidderNumber = 1,
            },
            new()
            {
                LotLead = "Lot 2",
                LotNumber = "2",
                LotNumberSort = 2,
                LotNumberSubSort = 2,
                Quantity = 1,
                QuantitySold = 1,
                Status = "SOLD",
                BoughtByBidderNumber = 1,
            },
            new()
            {
                LotLead = "Lot 3",
                LotNumber = "3",
                LotNumberSort = 3,
                LotNumberSubSort = 3,
                Quantity = 1,
                QuantitySold = 1,
                Status = "SOLD",
                BoughtByBidderNumber = 2,
            },
        ],
        OrganizationAddress1 = "123 Oak Street",
        OrganizationAddress2 = "Suite C",
        OrganizationCity = "Metropolis",
        OrganizationName = "Bob's Auctions",
        OrganizationPhone = "1234567890",
        OrganizationState = "KS",
        OrganizationZip = "99887",
    };

    public static readonly List<BuyerDataset> SAMPLE_BUYERS =
    [
        new()
        {
            Balance = 123.45m,
            BidderNumber = 1,
            BillToAddress1 = "123 Main Street",
            BillToAddress2 = "Suite A",
            BillToCity = "Anytown",
            BillToCountry = "USA",
            BillToState = "KY",
            BillToZip = "55555",
            Company = "Acme, Inc.",
            CustomerCode = "C123",
            CustomerId = 123,
            Email = "jdoe@example.com",
            FirstName = "John",
            InvoiceNumber = "000003",
            LastName = "Doe",
            MiddleName = "Elmo",
            Phone1 = "5552223333",
            Phone2 = "5551234567",
            ShipToAddress1 = "321 Elm Street",
            ShipToAddress2 = "Suite B",
            ShipToCity = "Anycity",
            ShipToCountry = "USA",
            ShipToState = "HI",
            ShipToZip = "44444",
        },
        new()
        {
            Balance = 678.90m,
            BidderNumber = 2,
            BillToAddress1 = "456 Main Street",
            BillToAddress2 = "Suite A",
            BillToCity = "Anytown",
            BillToCountry = "USA",
            BillToState = "KY",
            BillToZip = "88888",
            Company = "Acme, Inc.",
            CustomerCode = "C456",
            CustomerId = 456,
            Email = "janedoe@example.com",
            FirstName = "Jane",
            InvoiceNumber = "000007",
            LastName = "Doe",
            MiddleName = "Elmo",
            Phone1 = "5552223333",
            Phone2 = "5551234567",
            ShipToAddress1 = "654 Elm Street",
            ShipToAddress2 = "Suite B",
            ShipToCity = "Anycity",
            ShipToCountry = "USA",
            ShipToState = "HI",
            ShipToZip = "88888"
        }
    ];

    public static readonly ClerkedLotsCustomersDataset SAMPLE_SETTLEMENT = new()
	{
		CustomerId = 123,
		Balance = 71.10m,
		BidderNumber = 1,
		CustomerCode = "C1",
		Email = "sample@example.com",
		FirstName = "John",
		LastName = "Doe",
		HiBidBuyerId = null,
		IsHiBidCashBuyer = false,
		LotCount = 1,
		SettlementLines =
		[
			new()
			{
				LotGroup = "Group 1",
				Lead = "Test Lot 1",
				Description = "This is lot 1's description.",
				LotNumber = "1",
				QuantitySold = 1,
				Entries = 
				[
					new()
					{
						Amount = 55.55m,
						Description = "Lot Number 1",
						IsDebit = true,
						JournalId = 1,
						Type = TransactionType.LOT_SETTLEMENT
					}
				]
			},
			new()
			{
				LotGroup = "Group 1",
				Lead = "Test Lot 2",
				Description = "This is the description for Lot2.",
				LotNumber = "2",
				QuantitySold = 2,
				VINSerialNumber = "SN12345",
				StockNumber = "54321",
				Entries =
				[
					new()
					{
						Amount = 55.55m,
						Description = "Lot Number 2",
						IsDebit = true,
						JournalId = 1,
						Type = TransactionType.LOT_SETTLEMENT
					},
					new()
					{
						Amount = 5.56m,
						Description = "10% Buyer Tax",
						IsDebit = true,
						JournalId = 1,
						Type = TransactionType.BUYER_TAX
					},
					new()
					{
						Amount = 9.99m,
						Description = "Buyer Lot Charge",
						IsDebit = true,
						JournalId = 1,
						Type = TransactionType.BUYER_LOT_CHARGES
					}
				]
			},
			new()
			{
				LotGroup = "Group 2",
				Lead = "Test Lot 3",
				Description = "This is lot 3's description.",
				LotNumber = "1",
				QuantitySold = 1,
				Entries = 
				[
					new()
					{
						Amount = 77.88m,
						Description = "Lot Number 1",
						IsDebit = true,
						JournalId = 1,
						Type = TransactionType.LOT_SETTLEMENT
					}
				]
			},
			new()
			{
				LotGroup = string.Empty,
				Lead = "Test Lot 3",
				Description = "This is lot 3's description.",
				LotNumber = "1",
				QuantitySold = 1,
				Entries =
				[
					new()
					{
						Amount = 111.22m,
						Description = "Lot Number 4",
						IsDebit = true,
						JournalId = 1,
						Type = TransactionType.LOT_SETTLEMENT
					}
				]
			}
		],
		GroupedChargeLines =
		[
			new()
			{
				Description = "10% Buyer Tax",
				Amount = 5.56m
			},
			new()
			{
				Description = "Shipping",
				Amount = 9.99m
			}
		]
	};
}